pub struct ArtifactTemplate {
pub id: ArtifactTemplateId,
pub name: I18nString,
pub description: I18nString,
pub world_law: Option<ArtifactWorldLaw>,
pub ownership_bonuses: Vec<ArtifactOwnershipBonusStat>,
pub icon_path: String,
pub power_q: f64,
}Expand description
One entry of the artifact catalog.
Fields
id: ArtifactTemplateIdname: I18nStringdescription: I18nStringworld_law: Option<ArtifactWorldLaw>The welded-in rule, or None for an artifact that is a bare frame.
ownership_bonuses: Vec<ArtifactOwnershipBonusStat>What owning this artifact pays, per attribute. Empty = pays nothing.
Fully per-template: any set of attributes, any values. Every owned artifact pays — worn or not — which is the one thing that makes a second artifact worth having once only one can be worn.
icon_path: Stringpower_q: f64Trait Implementations
Sourceimpl Clone for ArtifactTemplate
impl Clone for ArtifactTemplate
Sourcefn clone(&self) -> ArtifactTemplate
fn clone(&self) -> ArtifactTemplate
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArtifactTemplate
impl Debug for ArtifactTemplate
Sourceimpl<'de> Deserialize<'de> for ArtifactTemplate
impl<'de> Deserialize<'de> for ArtifactTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ArtifactTemplate> for JsValuewhere
ArtifactTemplate: Serialize,
impl From<ArtifactTemplate> for JsValuewhere
ArtifactTemplate: Serialize,
Sourcefn from(value: ArtifactTemplate) -> Self
fn from(value: ArtifactTemplate) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for ArtifactTemplatewhere
Self: DeserializeOwned,
impl FromWasmAbi for ArtifactTemplatewhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for ArtifactTemplatewhere
ArtifactTemplate: Serialize,
impl IntoWasmAbi for ArtifactTemplatewhere
ArtifactTemplate: Serialize,
Sourceimpl JsonSchema for ArtifactTemplate
impl JsonSchema for ArtifactTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for ArtifactTemplatewhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for ArtifactTemplatewhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for ArtifactTemplatewhere
ArtifactTemplate: Serialize,
impl OptionIntoWasmAbi for ArtifactTemplatewhere
ArtifactTemplate: Serialize,
Sourceimpl RefFromWasmAbi for ArtifactTemplatewhere
Self: DeserializeOwned,
impl RefFromWasmAbi for ArtifactTemplatewhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<ArtifactTemplate>
type Anchor = SelfOwner<ArtifactTemplate>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for ArtifactTemplate
impl Serialize for ArtifactTemplate
Sourceimpl Tsify for ArtifactTemplate
impl Tsify for ArtifactTemplate
const DECL: &'static str = "/**\n * One entry of the artifact catalog.\n */\nexport interface ArtifactTemplate {\n id: ArtifactTemplateId;\n name: I18nString;\n description: I18nString;\n /**\n * The welded-in rule, or `None` for an artifact that is a bare frame.\n */\n world_law: ArtifactWorldLaw | null;\n /**\n * What owning this artifact pays, per attribute. Empty = pays nothing.\n *\n * Fully per-template: any set of attributes, any values. Every owned\n * artifact pays \u{2014} worn or not \u{2014} which is the one thing that makes a second\n * artifact worth having once only one can be worn.\n */\n ownership_bonuses: ArtifactOwnershipBonusStat[];\n icon_path: string;\n power_q: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for ArtifactTemplatewhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for ArtifactTemplatewhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for ArtifactTemplatewhere
ArtifactTemplate: Serialize,
impl VectorIntoWasmAbi for ArtifactTemplatewhere
ArtifactTemplate: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for ArtifactTemplate
impl WasmDescribeVector for ArtifactTemplate