pub struct ArtifactTierMagnitude {
pub tier: StoneTier,
pub magnitude: f64,
}Expand description
One rung of VA-05 Small Gears: how strongly effects run when the trigger
that fired them has this tier.
Carried on the template rather than hard-coded so the rule’s whole content is visible in the catalog while it waits for the Legendary tier to exist.
Fields
tier: StoneTiermagnitude: f64Trait Implementations
Sourceimpl Clone for ArtifactTierMagnitude
impl Clone for ArtifactTierMagnitude
Sourcefn clone(&self) -> ArtifactTierMagnitude
fn clone(&self) -> ArtifactTierMagnitude
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArtifactTierMagnitude
impl Debug for ArtifactTierMagnitude
Sourceimpl<'de> Deserialize<'de> for ArtifactTierMagnitude
impl<'de> Deserialize<'de> for ArtifactTierMagnitude
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ArtifactTierMagnitude> for JsValuewhere
ArtifactTierMagnitude: Serialize,
impl From<ArtifactTierMagnitude> for JsValuewhere
ArtifactTierMagnitude: Serialize,
Sourcefn from(value: ArtifactTierMagnitude) -> Self
fn from(value: ArtifactTierMagnitude) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for ArtifactTierMagnitudewhere
Self: DeserializeOwned,
impl FromWasmAbi for ArtifactTierMagnitudewhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for ArtifactTierMagnitudewhere
ArtifactTierMagnitude: Serialize,
impl IntoWasmAbi for ArtifactTierMagnitudewhere
ArtifactTierMagnitude: Serialize,
Sourceimpl JsonSchema for ArtifactTierMagnitude
impl JsonSchema for ArtifactTierMagnitude
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for ArtifactTierMagnitudewhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for ArtifactTierMagnitudewhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for ArtifactTierMagnitudewhere
ArtifactTierMagnitude: Serialize,
impl OptionIntoWasmAbi for ArtifactTierMagnitudewhere
ArtifactTierMagnitude: Serialize,
Sourceimpl RefFromWasmAbi for ArtifactTierMagnitudewhere
Self: DeserializeOwned,
impl RefFromWasmAbi for ArtifactTierMagnitudewhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<ArtifactTierMagnitude>
type Anchor = SelfOwner<ArtifactTierMagnitude>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for ArtifactTierMagnitude
impl Serialize for ArtifactTierMagnitude
Sourceimpl Tsify for ArtifactTierMagnitude
impl Tsify for ArtifactTierMagnitude
const DECL: &'static str = "/**\n * One rung of `VA-05 Small Gears`: how strongly effects run when the trigger\n * that fired them has this tier.\n *\n * Carried on the template rather than hard-coded so the rule\\\'s whole content is\n * visible in the catalog while it waits for the Legendary tier to exist.\n */\nexport interface ArtifactTierMagnitude {\n tier: StoneTier;\n magnitude: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for ArtifactTierMagnitudewhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for ArtifactTierMagnitudewhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for ArtifactTierMagnitudewhere
ArtifactTierMagnitude: Serialize,
impl VectorIntoWasmAbi for ArtifactTierMagnitudewhere
ArtifactTierMagnitude: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for ArtifactTierMagnitude
impl WasmDescribeVector for ArtifactTierMagnitude
impl Copy for ArtifactTierMagnitude