pub struct ArtifactUpgradeStep {
pub level: i64,
pub copies: i64,
}Expand description
Ownership stat bonus of ONE artifact at a given level, in percent.
One rung of an upgrade ladder: how many raw copies buy level.
Used by both ladders — artifacts and artifact stones. In both cases a duplicate banks a raw copy and an explicit player action spends the rung.
Fields
level: i64copies: i64Trait Implementations
Sourceimpl Clone for ArtifactUpgradeStep
impl Clone for ArtifactUpgradeStep
Sourcefn clone(&self) -> ArtifactUpgradeStep
fn clone(&self) -> ArtifactUpgradeStep
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArtifactUpgradeStep
impl Debug for ArtifactUpgradeStep
Sourceimpl<'de> Deserialize<'de> for ArtifactUpgradeStep
impl<'de> Deserialize<'de> for ArtifactUpgradeStep
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ArtifactUpgradeStep> for JsValuewhere
ArtifactUpgradeStep: Serialize,
impl From<ArtifactUpgradeStep> for JsValuewhere
ArtifactUpgradeStep: Serialize,
Sourcefn from(value: ArtifactUpgradeStep) -> Self
fn from(value: ArtifactUpgradeStep) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for ArtifactUpgradeStepwhere
Self: DeserializeOwned,
impl FromWasmAbi for ArtifactUpgradeStepwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for ArtifactUpgradeStepwhere
ArtifactUpgradeStep: Serialize,
impl IntoWasmAbi for ArtifactUpgradeStepwhere
ArtifactUpgradeStep: Serialize,
Sourceimpl JsonSchema for ArtifactUpgradeStep
impl JsonSchema for ArtifactUpgradeStep
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for ArtifactUpgradeStepwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for ArtifactUpgradeStepwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for ArtifactUpgradeStepwhere
ArtifactUpgradeStep: Serialize,
impl OptionIntoWasmAbi for ArtifactUpgradeStepwhere
ArtifactUpgradeStep: Serialize,
Sourceimpl RefFromWasmAbi for ArtifactUpgradeStepwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for ArtifactUpgradeStepwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<ArtifactUpgradeStep>
type Anchor = SelfOwner<ArtifactUpgradeStep>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for ArtifactUpgradeStep
impl Serialize for ArtifactUpgradeStep
Sourceimpl Tsify for ArtifactUpgradeStep
impl Tsify for ArtifactUpgradeStep
const DECL: &'static str = "/**\n * Ownership stat bonus of ONE artifact at a given level, in percent.\n *\n * One rung of an upgrade ladder: how many raw copies buy `level`.\n *\n * Used by both ladders \u{2014} artifacts and artifact stones. In both cases a\n * duplicate banks a raw copy and an explicit player action spends the rung.\n */\nexport interface ArtifactUpgradeStep {\n level: number;\n copies: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for ArtifactUpgradeStepwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for ArtifactUpgradeStepwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for ArtifactUpgradeStepwhere
ArtifactUpgradeStep: Serialize,
impl VectorIntoWasmAbi for ArtifactUpgradeStepwhere
ArtifactUpgradeStep: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for ArtifactUpgradeStep
impl WasmDescribeVector for ArtifactUpgradeStep
impl Copy for ArtifactUpgradeStep